@@ -145,31 +145,5 @@ my $exe = $CC->link_executable(
                            $Config{'archlib'} . '/CORE/' . $Config{'libperl'},
                       ]
 );
-printf system('./' . $exe) ? 'Aww...' : 'Yay! %s bytes', -s $exe;
+printf system($exe) ? 'Aww...' : 'Yay! %s bytes', -s $exe;
 END { unlink grep defined, $source, $obj, $exe; }
-
-=pod
-
-=head1 Author
-
-Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
-
-CPAN ID: SANKO
-
-=head1 License and Legal
-
-Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
-
-This program is free software; you can redistribute it and/or modify it under
-the terms of The Artistic License 2.0. See the F<LICENSE> file included with
-this distribution or http://www.perlfoundation.org/artistic_license_2_0.  For
-clarification, see http://www.perlfoundation.org/artistic_2_0_notes.
-
-When separated from the distribution, all POD documentation is covered by the
-Creative Commons Attribution-Share Alike 3.0 License. See
-http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
-clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
-
-=for git $Id: 0001_embed.pl e048451 2009-09-02 03:23:06Z sanko@cpan.org $
-
-=cut
