@@ -4,7 +4,7 @@ package MBX::Alien::FLTK::Win32;
     use warnings;
     use Carp qw[];
     use Config qw[%Config];
-    use lib qw[.. ../../../];
+    use lib qw[.. ../..];
     use MBX::Alien::FLTK::Utility qw[_o _a _dir _rel _abs];
     use base 'MBX::Alien::FLTK';
     sub new { bless \$0, shift }
@@ -191,14 +191,9 @@ END
         my ($self, $build) = @_;
         my @lib;
         for my $dir (sort keys %LIBS) {
-            if (!chdir $build->base_dir()) {
-                print '...you can\'t go home again.';
-                exit 0;
-            }
-            if (!chdir $build->fltk_dir() . "/$dir") {
-                print 'Cannot chdir to ' . $build->fltk_dir() . '/' . $dir;
-                exit 0;
-            }
+            chdir $build->base_dir() or die q[Can't go home again!];
+            chdir $build->fltk_dir() . "/$dir"
+                or die 'Cannot chdir to ' . $build->fltk_dir() . '/' . $dir;
             print "=== making $dir ===\n";
             for my $lib (sort keys %{$LIBS{$dir}}) {
                 my @obj;
@@ -230,10 +225,7 @@ END
                             );
                         }
                         ->();
-                    if (!$obj) {
-                        printf 'Failed to compile %s', $src;
-                        exit 0;
-                    }
+                    die sprintf 'Failed to compile %s', $src if !$obj;
                     push @obj, $obj;
                 }
                 my $_lib = _rel(_dir($build->fltk_dir, 'lib', _a($lib)));
@@ -245,17 +237,13 @@ END
                                       verbose => $build->VERBOSE()
                                      }
                     );
-                if (!$lib) {
-                    printf 'Failed to create %s library', $lib;
-                    exit 0;
-                }
+                die sprintf 'Failed to create %s library', $lib
+                    if !$lib;
                 push @lib, _abs($lib);
             }
         }
-        if (!chdir $build->fltk_dir($self)) {
-            print 'Failed to cd to fltk\'s base directory';
-            exit 0;
-        }
+        chdir $build->fltk_dir($self)
+            or die q[failed to cd to fltk's base directory];
         return @lib ? 1 : 0;
     }
 
@@ -278,29 +266,6 @@ END
     }
     1;
 }
+__END__
 
-=pod
-
-=head1 Author
-
-Sanko Robinson <sanko@cpan.org> - http://sankorobinson.com/
-
-CPAN ID: SANKO
-
-=head1 License and Legal
-
-Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
-
-This program is free software; you can redistribute it and/or modify it under
-the terms of The Artistic License 2.0. See the F<LICENSE> file included with
-this distribution or http://www.perlfoundation.org/artistic_license_2_0.  For
-clarification, see http://www.perlfoundation.org/artistic_2_0_notes.
-
-When separated from the distribution, all POD documentation is covered by the
-Creative Commons Attribution-Share Alike 3.0 License. See
-http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
-clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
-
-=for git $Id: Win32.pm 0851106 2009-08-26 02:37:39Z sanko@cpan.org $
-
-=cut
+$Id: Win32.pm b07aa6c 2009-08-22 05:23:41Z sanko@cpan.org $
